=====
Array
=====

The following methods are available under the `expr.arr` attribute.

.. currentmodule:: polars
.. autosummary::
   :toctree: api/
   :template: autosummary/accessor_method.rst

    Expr.arr.max
    Expr.arr.min
    Expr.arr.sum
    Expr.arr.unique
